mecab_node_t

Struct mecab_node_t 

#[repr(C)]
pub struct mecab_node_t {
Show 22 fields pub prev: *mut mecab_node_t, pub next: *mut mecab_node_t, pub enext: *mut mecab_node_t, pub bnext: *mut mecab_node_t, pub rpath: *mut mecab_path_t, pub lpath: *mut mecab_path_t, pub surface: *const c_char, pub feature: *const c_char, pub id: c_uint, pub length: c_ushort, pub rlength: c_ushort, pub rcAttr: c_ushort, pub lcAttr: c_ushort, pub posid: c_ushort, pub char_type: c_uchar, pub stat: c_uchar, pub isbest: c_uchar, pub alpha: f32, pub beta: f32, pub prob: f32, pub wcost: c_short, pub cost: c_long,
}
Node structure

Fields

prev: *mut mecab_node_t

pointer to the previous node.

next: *mut mecab_node_t

pointer to the next node.

enext: *mut mecab_node_t

pointer to the node which ends at the same position.

bnext: *mut mecab_node_t

pointer to the node which starts at the same position.

rpath: *mut mecab_path_t

pointer to the right path. this value is NULL if MECAB_ONE_BEST mode.

lpath: *mut mecab_path_t

pointer to the right path. this value is NULL if MECAB_ONE_BEST mode.

surface: *const c_char

surface string. this value is not 0 terminated. You can get the length with length/rlength members.

feature: *const c_char

feature string

id: c_uint

unique node id

length: c_ushort

length of the surface form.

rlength: c_ushort

length of the surface form including white space before the morph.

rcAttr: c_ushort

right attribute id

lcAttr: c_ushort

left attribute id

posid: c_ushort

unique part of speech id. This value is defined in “pos.def” file.

char_type: c_uchar

character type

stat: c_uchar

status of this model. This value is MECAB_NOR_NODE, MECAB_UNK_NODE, MECAB_BOS_NODE, MECAB_EOS_NODE, or MECAB_EON_NODE.

isbest: c_uchar

set 1 if this node is best node.

alpha: f32

forward accumulative log summation. This value is only available when MECAB_MARGINAL_PROB is passed.

beta: f32

backward accumulative log summation. This value is only available when MECAB_MARGINAL_PROB is passed.

prob: f32

marginal probability. This value is only available when MECAB_MARGINAL_PROB is passed.

wcost: c_short

word cost.

cost: c_long

best accumulative cost from bos node to this node.