#[repr(C)]pub struct mecab_node_t {Show 22 fields
pub prev: *mut mecab_node_t,
pub next: *mut mecab_node_t,
pub enext: *mut mecab_node_t,
pub bnext: *mut mecab_node_t,
pub rpath: *mut mecab_path_t,
pub lpath: *mut mecab_path_t,
pub surface: *const c_char,
pub feature: *const c_char,
pub id: c_uint,
pub length: c_ushort,
pub rlength: c_ushort,
pub rcAttr: c_ushort,
pub lcAttr: c_ushort,
pub posid: c_ushort,
pub char_type: c_uchar,
pub stat: c_uchar,
pub isbest: c_uchar,
pub alpha: f32,
pub beta: f32,
pub prob: f32,
pub wcost: c_short,
pub cost: c_long,
}Expand description
Node structure
Fields
prev: *mut mecab_node_tpointer to the previous node.
next: *mut mecab_node_tpointer to the next node.
enext: *mut mecab_node_tpointer to the node which ends at the same position.
bnext: *mut mecab_node_tpointer to the node which starts at the same position.
rpath: *mut mecab_path_tpointer to the right path. this value is NULL if MECAB_ONE_BEST mode.
lpath: *mut mecab_path_tpointer to the right path. this value is NULL if MECAB_ONE_BEST mode.
surface: *const c_charsurface string. this value is not 0 terminated. You can get the length with length/rlength members.
feature: *const c_charfeature string
id: c_uintunique node id
length: c_ushortlength of the surface form.
rlength: c_ushortlength of the surface form including white space before the morph.
rcAttr: c_ushortright attribute id
lcAttr: c_ushortleft attribute id
posid: c_ushortunique part of speech id. This value is defined in “pos.def” file.
char_type: c_ucharcharacter type
stat: c_ucharstatus of this model. This value is MECAB_NOR_NODE, MECAB_UNK_NODE, MECAB_BOS_NODE, MECAB_EOS_NODE, or MECAB_EON_NODE.
isbest: c_ucharset 1 if this node is best node.
alpha: f32forward accumulative log summation. This value is only available when MECAB_MARGINAL_PROB is passed.
beta: f32backward accumulative log summation. This value is only available when MECAB_MARGINAL_PROB is passed.
prob: f32marginal probability. This value is only available when MECAB_MARGINAL_PROB is passed.
wcost: c_shortword cost.
cost: c_longbest accumulative cost from bos node to this node.