Node

Struct Node 

pub struct Node<'a> { /* private fields */ }
A single node (morpheme) in the MeCab lattice. It wraps C mecab_node_t.

The lifetime parameter is bound to Lattice and the input sentence.

Implementations

Source

impl<'a> Node<'a>

pub fn as_ptr(&self) -> *mut mecab_node_t

Returns the raw pointer to the underlying mecab_node_t.

pub fn next(self) -> Option<Self>

Returns the next node in the same lattice.

It wraps mecab_node_t::next.

None is likely to imply that self is EoS.

pub fn prev(self) -> Option<Self>

Returns the previous node in the same lattice.

It wraps mecab_node_t::prev.

None is likely to imply that self is BoS.

pub fn id(self) -> u32

Returns the unique node ID.

It wraps mecab_node_t::id.

pub fn feature(self) -> &'a str

Returns the feature string of this node.

It wraps mecab_node_t::feature.

pub fn surface(self) -> &'a str

Returns the surface string of this node.

It wraps mecab_node_t::surface and mecab_node_t::length.

pub fn kind(self) -> NodeKind

Returns the status of this node.

It wraps mecab_node_t::stat.

pub fn lc_attr(self) -> LcAttr

Returns the left attribute ID.

It wraps mecab_node_t::lcAttr.

pub fn rc_attr(self) -> RcAttr

Returns the right attribute ID.

It wraps mecab_node_t::rcAttr.

pub fn pos_id(self) -> u16

Returns the unique part of speech ID.

It wraps mecab_node_t::posid.

pub fn char_type(self) -> u8

Returns the character type ID.

It wraps mecab_node_t::char_type.

pub fn is_best(self) -> bool

Returns true if this node is part of the best path.

It wraps mecab_node_t::isbest.

pub fn alpha(self) -> f32

Returns the forward accumulative log summation.

It wraps mecab_node_t::alpha.

pub fn beta(self) -> f32

Returns the backward accumulative log summation.

It wraps mecab_node_t::beta.

pub fn prob(self) -> f32

Returns the marginal probability.

It wraps mecab_node_t::prob.

pub fn wcost(self) -> i16

Returns the word cost.

It wraps mecab_node_t::wcost.

pub fn cost(self) -> i64

Returns the best accumulative cost from BoS to this node.

It wraps mecab_node_t::cost.